@@ -98,7 +98,7 @@ BaremetalGroup = [
                help="Timeout for association of Nova instance and Ironic "
                     "node"),
     cfg.IntOpt('inspect_timeout',
-               default=10,
+               default=300,
                help="Timeout for inspecting an Ironic node."),
     cfg.IntOpt('power_timeout',
                default=60,
@@ -203,6 +203,9 @@ BaremetalGroup = [
     cfg.ListOpt('enabled_power_interfaces',
                 default=['fake', 'ipmitool'],
                 help="List of Ironic enabled power interfaces."),
+    cfg.ListOpt('enabled_inspect_interfaces',
+                default=['no-inspect'],
+                help="List of Ironic enabled inspect interfaces."),
     cfg.StrOpt('default_rescue_interface',
                help="Ironic default rescue interface."),
     cfg.StrOpt('firmware_image_url',
@@ -242,7 +245,9 @@ BaremetalGroup = [
                 default=True,
                 help="If we should issue a rebuild request when testing "
                      "dhcpless virtual media deployments. This may be useful "
-                     "if bug 2032377 is not fixed in the agent ramdisk."),
+                     "if bug 2032377 is not fixed in the agent ramdisk. This "
+                     "test is functionally incompatible with Temporary URLs "
+                     "as they may timeout while the test is running."),
     cfg.StrOpt("public_subnet_id",
                help="The public subnet ID where routers will be bound for "
                     "testing purposes with the dhcp-less test scenario."),
