@@ -25,96 +25,6 @@ from ironic_tempest_plugin.tests.scenario import \
 CONF = config.CONF
 
 
-class BaremetalAgentIpmitoolWholedisk(bsm.BaremetalStandaloneScenarioTest):
-
-    driver = 'agent_ipmitool'
-    image_ref = CONF.baremetal.whole_disk_image_ref
-    wholedisk_image = True
-
-    @decorators.idempotent_id('defff515-a6ff-44f6-9d8d-2ded51196d98')
-    @utils.services('image', 'network', 'object_storage')
-    def test_ip_access_to_server(self):
-        self.boot_and_verify_node()
-
-
-class BaremetalAgentIpmitoolWholediskHttpLink(
-        bsm.BaremetalStandaloneScenarioTest):
-
-    driver = 'agent_ipmitool'
-    image_ref = CONF.baremetal.whole_disk_image_url
-    image_checksum = CONF.baremetal.whole_disk_image_checksum
-    wholedisk_image = True
-
-    @classmethod
-    def skip_checks(cls):
-        super(BaremetalAgentIpmitoolWholediskHttpLink, cls).skip_checks()
-        if not CONF.baremetal_feature_enabled.ipxe_enabled:
-            skip_msg = ("HTTP server is not available when ipxe is disabled.")
-            raise cls.skipException(skip_msg)
-
-    @decorators.idempotent_id('d926c683-1a32-44df-afd0-e60134346fd0')
-    @utils.services('network')
-    def test_ip_access_to_server(self):
-        self.boot_and_verify_node()
-
-
-class BaremetalAgentIpmitoolPartitioned(bsm.BaremetalStandaloneScenarioTest):
-
-    driver = 'agent_ipmitool'
-    image_ref = CONF.baremetal.partition_image_ref
-    wholedisk_image = False
-
-    @decorators.idempotent_id('27b86130-d8dc-419d-880a-fbbbe4ce3f8c')
-    @utils.services('image', 'network', 'object_storage')
-    def test_ip_access_to_server(self):
-        self.boot_and_verify_node()
-
-
-class BaremetalPxeIpmitoolWholedisk(bsm.BaremetalStandaloneScenarioTest):
-
-    driver = 'pxe_ipmitool'
-    image_ref = CONF.baremetal.whole_disk_image_ref
-    wholedisk_image = True
-
-    @decorators.idempotent_id('d8c5badd-45db-4d05-bbe8-35babbed6e86')
-    @utils.services('image', 'network')
-    def test_ip_access_to_server(self):
-        self.boot_and_verify_node()
-
-
-class BaremetalPxeIpmitoolWholediskHttpLink(
-        bsm.BaremetalStandaloneScenarioTest):
-
-    driver = 'pxe_ipmitool'
-    image_ref = CONF.baremetal.whole_disk_image_url
-    image_checksum = CONF.baremetal.whole_disk_image_checksum
-    wholedisk_image = True
-
-    @classmethod
-    def skip_checks(cls):
-        super(BaremetalPxeIpmitoolWholediskHttpLink, cls).skip_checks()
-        if not CONF.baremetal_feature_enabled.ipxe_enabled:
-            skip_msg = ("HTTP server is not available when ipxe is disabled.")
-            raise cls.skipException(skip_msg)
-
-    @decorators.idempotent_id('71ccf06f-6765-40fd-8252-1b1bfa423b9b')
-    @utils.services('network')
-    def test_ip_access_to_server(self):
-        self.boot_and_verify_node()
-
-
-class BaremetalPxeIpmitoolPartitioned(bsm.BaremetalStandaloneScenarioTest):
-
-    driver = 'pxe_ipmitool'
-    image_ref = CONF.baremetal.partition_image_ref
-    wholedisk_image = False
-
-    @decorators.idempotent_id('ea85e19c-6869-4577-b9bb-2eb150f77c90')
-    @utils.services('image', 'network')
-    def test_ip_access_to_server(self):
-        self.boot_and_verify_node()
-
-
 class BaremetalDriverIscsiWholedisk(bsm.BaremetalStandaloneScenarioTest):
 
     api_microversion = '1.31'  # to set the deploy_interface
@@ -700,3 +610,88 @@ class BaremetalRedfishIPxeAnacondaNoGlance(
             kernel_ref=CONF.baremetal.anaconda_kernel_ref,
             ramdisk_ref=CONF.baremetal.anaconda_initial_ramdisk_ref,
             stage2_ref=CONF.baremetal.anaconda_stage2_ramdisk_ref)
+
+
+class BaremetalChangeBaseBootInterface(
+        bsm.BaremetalStandaloneScenarioTest):
+
+    # NOTE(TheJulia): The resource setup class *already* auto-sets the
+    # requested boot interface. We just never tried to articulate
+    # this sort of configuration before this class.
+    # The goal: Test as many boot interfaces to ensure they are functional
+    # under the base context
+
+    api_microversion = '1.31'  # to set the boot_interface
+    driver = None
+    # This is intentionally meant to be a relatively light weight test,
+    # but one that covers the common cases, i.e. direct is most appropriate
+    # here. Ramdisk/anaconda/ansible and friends are all more specific
+    # cased.
+    deploy_interface = 'direct'
+    image_ref = CONF.baremetal.whole_disk_image_url
+    image_checksum = CONF.baremetal.whole_disk_image_checksum
+    wholedisk_image = True
+
+    # This is a special override which allows us to just use the base
+    # driver interface defined on the node, and not have to special case it
+    # and focus on the "driver".
+    use_available_driver = True
+
+    # List of valid drivers which these tests *can* attempt to utilize.
+    # Generally these should be the most commom, stock, upstream drivers.
+    valid_driver_list = ['ipmi', 'redfish']
+
+    # Bypass secondary attribute presence check as these tests don't require
+    # the driver to be set.
+    mandatory_attr = ['image_ref']
+
+
+class BaremetalPXEBootTestClass(BaremetalChangeBaseBootInterface):
+
+    boot_interface = 'pxe'
+
+    @decorators.idempotent_id('62c12d2c-8c9f-4526-b9ab-b9cd63e0ea8a')
+    @utils.services('network')
+    def test_ip_access_to_server(self):
+        self.boot_and_verify_node()
+
+
+class BaremetalIPXEBootTestClass(BaremetalChangeBaseBootInterface):
+
+    boot_interface = 'ipxe'
+
+    @decorators.idempotent_id('113acd0a-9872-4631-b3ee-54da7e3bb262')
+    @utils.services('network')
+    def test_ip_access_to_server(self):
+        self.boot_and_verify_node()
+
+
+class BaremetalHTTPBootTestClass(BaremetalChangeBaseBootInterface):
+
+    boot_interface = 'http'
+
+    @decorators.idempotent_id('782c43db-77a1-4a3a-b46e-0ce9cbb7fba5')
+    @utils.services('network')
+    def test_ip_access_to_server(self):
+        self.boot_and_verify_node()
+
+
+class BaremetalHttpIPXEBootTestClass(BaremetalChangeBaseBootInterface):
+
+    boot_interface = 'http-ipxe'
+
+    @decorators.idempotent_id('45400d8e-55a5-4ba6-81f5-935a4183ed90')
+    @utils.services('network')
+    def test_ip_access_to_server(self):
+        self.boot_and_verify_node()
+
+
+class BaremetalRedfishVmediaBootTestClass(BaremetalChangeBaseBootInterface):
+
+    boot_interface = 'redfish-virtual-media'
+    driver = 'redfish'
+
+    @decorators.idempotent_id('10535270-27e5-4616-9013-9507b1960dfa')
+    @utils.services('network')
+    def test_ip_access_to_server(self):
+        self.boot_and_verify_node()
