@@ -51,12 +51,12 @@ class BaremetalMultitenancy(baremetal_manager.BaremetalScenarioTest,
             raise cls.skipException(msg)
 
     def create_tenant_network(self, clients, tenant_cidr):
-        network = self._create_network(
+        network = self.create_network(
             networks_client=clients.networks_client,
-            tenant_id=clients.credentials.tenant_id)
-        router = self._get_router(
+            project_id=clients.credentials.project_id)
+        router = self.get_router(
             client=clients.routers_client,
-            tenant_id=clients.credentials.tenant_id)
+            project_id=clients.credentials.tenant_id)
 
         result = clients.subnets_client.create_subnet(
             name=data_utils.rand_name('subnet'),
@@ -104,7 +104,8 @@ class BaremetalMultitenancy(baremetal_manager.BaremetalScenarioTest,
             instance1,
         )['floating_ip_address']
         self.check_vm_connectivity(ip_address=floating_ip1,
-                                   private_key=keypair['private_key'])
+                                   private_key=keypair['private_key'],
+                                   server=instance1)
         if use_vm:
             # Create VM on compute node
             alt_instance = self.create_server(
@@ -127,7 +128,8 @@ class BaremetalMultitenancy(baremetal_manager.BaremetalScenarioTest,
         )['floating_ip_address']
         self.check_vm_connectivity(
             ip_address=alt_floating_ip,
-            private_key=alt_keypair['private_key'])
+            private_key=alt_keypair['private_key'],
+            server=alt_instance)
         self.verify_l3_connectivity(
             alt_floating_ip,
             alt_keypair['private_key'],
